@@ -2,8 +2,8 @@ from statistics import mean
 
 import matplotlib.pyplot as plt
 import numpy as np
-from src.OpenBacktest import divide, Colors, remove_fees, parse_timestamp
-from src.OpenBacktest import PositionBook, LongPosition
+from src.OpenBacktest.ObtUtility import divide, Colors, remove_fees, parse_timestamp
+from src.OpenBacktest.ObtPositions import PositionBook, LongPosition
 
 
 # ----------------------------------------------------------------------------------------------
